@@ -15,6 +15,7 @@ if TYPE_CHECKING:
     from typing import Set
     from typing import Type
     from typing import Union
+    from typing import Any
 
 
 _DEFAULT_FAILED_REQUEST_STATUS_CODES = frozenset(range(500, 600))
@@ -170,13 +171,19 @@ _MIN_VERSIONS = {
 }
 
 
+_INTEGRATION_DEACTIVATES = {
+    "langchain": {"openai", "anthropic"},
+}
+
+
 def setup_integrations(
-    integrations,
-    with_defaults=True,
-    with_auto_enabling_integrations=False,
-    disabled_integrations=None,
+    integrations,  # type: Sequence[Integration]
+    with_defaults=True,  # type: bool
+    with_auto_enabling_integrations=False,  # type: bool
+    disabled_integrations=None,  #  type: Optional[Sequence[Union[type[Integration], Integration]]]
+    options=None,  # type: Optional[Dict[str, Any]]
 ):
-    # type: (Sequence[Integration], bool, bool, Optional[Sequence[Union[type[Integration], Integration]]]) -> Dict[str, Integration]
+    # type: (...) -> Dict[str, Integration]
     """
     Given a list of integration instances, this installs them all.
 
@@ -185,6 +192,15 @@ def setup_integrations(
 
     `disabled_integrations` takes precedence over `with_defaults` and
     `with_auto_enabling_integrations`.
+
+    Some integrations are designed to automatically deactivate other integrations
+    in order to avoid conflicts and prevent duplicate telemetry from being collected.
+    For example, enabling the `langchain` integration will auto-deactivate both the
+    `openai` and `anthropic` integrations.
+
+    Users can override this behavior by:
+      - Explicitly providing an integration in the `integrations=[]` list, or
+      - Disabling the higher-level integration via the `disabled_integrations` option.
     """
     integrations = dict(
         (integration.identifier, integration) for integration in integrations or ()
@@ -192,6 +208,8 @@ def setup_integrations(
 
     logger.debug("Setting up integrations (with default = %s)", with_defaults)
 
+    user_provided_integrations = set(integrations.keys())
+
     # Integrations that will not be enabled
     disabled_integrations = [
         integration if isinstance(integration, type) else type(integration)
@@ -210,6 +228,27 @@ def setup_integrations(
                 integrations[instance.identifier] = instance
                 used_as_default_integration.add(instance.identifier)
 
+    disabled_integration_identifiers = {
+        integration.identifier for integration in disabled_integrations
+    }
+
+    for integration, targets_to_deactivate in _INTEGRATION_DEACTIVATES.items():
+        if (
+            integration in integrations
+            and integration not in disabled_integration_identifiers
+        ):
+            for target in targets_to_deactivate:
+                if target not in user_provided_integrations:
+                    for cls in iter_default_integrations(True):
+                        if cls.identifier == target:
+                            if cls not in disabled_integrations:
+                                disabled_integrations.append(cls)
+                                logger.debug(
+                                    "Auto-deactivating %s integration because %s integration is active",
+                                    target,
+                                    integration,
+                                )
+
     for identifier, integration in integrations.items():
         with _installer_lock:
             if identifier not in _processed_integrations:
@@ -221,6 +260,7 @@ def setup_integrations(
                     )
                     try:
                         type(integration).setup_once()
+                        integration.setup_once_with_options(options)
                     except DidNotEnable as e:
                         if identifier not in used_as_default_integration:
                             raise
@@ -300,3 +340,10 @@ class Integration(ABC):
         instance again.
         """
         pass
+
+    def setup_once_with_options(self, options=None):
+        # type: (Optional[Dict[str, Any]]) -> None
+        """
+        Called after setup_once in rare cases on the instance and with options since we don't have those available above.
+        """
+        pass
