@@ -1484,17 +1484,37 @@ class TimeoutThread(threading.Thread):
     waiting_time and raises a custom ServerlessTimeout exception.
     """
 
-    def __init__(self, waiting_time, configured_timeout):
-        # type: (float, int) -> None
+    def __init__(
+        self, waiting_time, configured_timeout, isolation_scope=None, current_scope=None
+    ):
+        # type: (float, int, Optional[sentry_sdk.Scope], Optional[sentry_sdk.Scope]) -> None
         threading.Thread.__init__(self)
         self.waiting_time = waiting_time
         self.configured_timeout = configured_timeout
+
+        self.isolation_scope = isolation_scope
+        self.current_scope = current_scope
+
         self._stop_event = threading.Event()
 
     def stop(self):
         # type: () -> None
         self._stop_event.set()
 
+    def _capture_exception(self):
+        # type: () -> ExcInfo
+        exc_info = sys.exc_info()
+
+        client = sentry_sdk.get_client()
+        event, hint = event_from_exception(
+            exc_info,
+            client_options=client.options,
+            mechanism={"type": "threading", "handled": False},
+        )
+        sentry_sdk.capture_event(event, hint=hint)
+
+        return exc_info
+
     def run(self):
         # type: () -> None
 
@@ -1510,6 +1530,18 @@ class TimeoutThread(threading.Thread):
             integer_configured_timeout = integer_configured_timeout + 1
 
         # Raising Exception after timeout duration is reached
+        if self.isolation_scope is not None and self.current_scope is not None:
+            with sentry_sdk.scope.use_isolation_scope(self.isolation_scope):
+                with sentry_sdk.scope.use_scope(self.current_scope):
+                    try:
+                        raise ServerlessTimeoutWarning(
+                            "WARNING : Function is expected to get timed out. Configured timeout duration = {} seconds.".format(
+                                integer_configured_timeout
+                            )
+                        )
+                    except Exception:
+                        reraise(*self._capture_exception())
+
         raise ServerlessTimeoutWarning(
             "WARNING : Function is expected to get timed out. Configured timeout duration = {} seconds.".format(
                 integer_configured_timeout
@@ -1728,6 +1760,12 @@ def _normalize_module_name(name):
     return name.lower()
 
 
+def _replace_hyphens_dots_and_underscores_with_dashes(name):
+    # type: (str) -> str
+    # https://peps.python.org/pep-0503/#normalized-names
+    return re.sub(r"[-_.]+", "-", name)
+
+
 def _get_installed_modules():
     # type: () -> Dict[str, str]
     global _installed_modules
@@ -1738,8 +1776,15 @@ def _get_installed_modules():
 
 def package_version(package):
     # type: (str) -> Optional[Tuple[int, ...]]
-    installed_packages = _get_installed_modules()
-    version = installed_packages.get(package)
+    normalized_package = _normalize_module_name(
+        _replace_hyphens_dots_and_underscores_with_dashes(package)
+    )
+
+    installed_packages = {
+        _replace_hyphens_dots_and_underscores_with_dashes(module): v
+        for module, v in _get_installed_modules().items()
+    }
+    version = installed_packages.get(normalized_package)
     if version is None:
         return None
 
@@ -2020,7 +2065,7 @@ def has_metrics_enabled(options):
     if options is None:
         return False
 
-    return bool(options["_experiments"].get("enable_metrics", False))
+    return bool(options.get("enable_metrics", True))
 
 
 def get_before_send_metric(options):
@@ -2028,4 +2073,6 @@ def get_before_send_metric(options):
     if options is None:
         return None
 
-    return options["_experiments"].get("before_send_metric")
+    return options.get("before_send_metric") or options["_experiments"].get(
+        "before_send_metric"
+    )
